@@ -16,5 +16,8 @@ weights <- function(nprobs, nexp, nseed, true.seed, qseed, qk, w)
 
     ## Compute aggregate distribution
     breaks <- drop(matrix(qseed[, nseed + 1, 1:nexp], ncol = nexp) %*% w)
-    list(breaks = breaks, probs = qk)
+
+    ## Results
+    structure(list(breaks = breaks, probs = qk),
+              method = "Predefined Weights")
 }
